@@ -15,7 +15,7 @@ use ObjectDB::Table;
 use ObjectDB::With;
 use ObjectDB::Util qw(execute filter_columns);
 
-our $VERSION = '3.27';
+our $VERSION = '3.28';
 
 $Carp::Internal{ (__PACKAGE__) }++;
 $Carp::Internal{"ObjectDB::$_"}++ for qw/
@@ -1017,6 +1017,10 @@ Converts object into a hash reference, including all preloaded objects.
 
 =back
 
+=head1 CREDITS
+
+kitt-vl (github/kitt-vl)
+
 =head1 AUTHOR
 
 Viacheslav Tykhanovskyi
